==> geti-0.0.1.tgz: package/index.js <==
#!/usr/bin/env node
import axios from 'axios';
import chalk from 'chalk';
import { Command } from 'commander';
import * as dotenv from 'dotenv';
import { createSpinner } from 'nanospinner';
import path from 'path';
import speedTest from 'speedtest-net';
import * as child_process from 'child_process';

const __dirname = path.resolve();

dotenv.config({ path: `${__dirname}/./.env` });
const weatherApiPrefix = process.env.OPENWEATHER_API_PREFIX;
const weatherApiKey = process.env.OPENWEATHER_API_KEY;
const googleApiPrefix = process.env.SEARCH_GOOGLE_API_PREFIX;
const youtubeApiPrefix = process.env.SEARCH_YOUTUBE_API_PREFIX;
const commander = new Command();

commander
  .command('weather')
  .alias('w')
  .description('Get weather')
  .action(() => getWeather());

commander
  .command('speed')
  .description('Run a speed test')
  .action(() => getSpeed());

commander
  .command('google')
  .alias('g')
  .description('Run a Google Search')
  .action(() => search(googleApiPrefix, 'Google'));

commander
  .command('youtube')
  .alias('y')
  .description('Run a Youtube Search')
  .action(() => search(youtubeApiPrefix, 'Youtube'));

commander.parse(process.argv);

async function getWeather() {
  // console.log(process.env)
  const spinner = createSpinner(`Loading weather`).start();
  // console.log(weatherApiPrefix);
  // console.log(weatherApiKey);
  const weather = await axios.get(
    `${weatherApiPrefix}?lat=35&lon=139&appid=${weatherApiKey}`
  );
  spinner.success({ text: `temp is ${chalk.blue(weather.data.main.temp)}.` });
}

async function getSpeed() {
  const spinner = createSpinner(`Running speed test`).start();
  const test = speedTest({ maxTime: 5000 });

  test.on('data', (data) => {
    spinner.success({
      text: `\nDownload ${chalk.green(
        data.speeds.download
      )} Mbps\nUpload ${chalk.magenta(
        data.speeds.upload
      )} Mbps\nPing ${chalk.blue(data.server.ping)} ms`,
    });
  });
  test.on('error', () => {
    spinner.error({ text: `\nAn error ocurred. Please try again` });
  });
}

function search(searchPrefix, searchType) {
  // console.log(process.argv);
  let searchQuery = '';
  if (process.argv.length > 2) {
    const queryArray = process.argv.slice(1);
    searchQuery = queryArray.join('+');
  }
  const searchAddress = searchPrefix + searchQuery;
  // console.log(searchAddress);
  const openCmd = process.platform === 'win32' ? 'start' : 'open';

  console.log(chalk.blue(`Searching on ${searchType}...`));
  setTimeout(() => {
    child_process.exec(`${openCmd} ${searchAddress}`, () => {});
  }, 300);
}

==> geti-0.0.3.tgz: package/index.js <==
#!/usr/bin/env node
import axios from 'axios';
import chalk from 'chalk';
import { Command } from 'commander';
import * as dotenv from 'dotenv';
import { createSpinner } from 'nanospinner';
import path from 'path';
import speedTest from 'speedtest-net';
import * as child_process from 'child_process';

const __dirname = path.resolve();

dotenv.config({ path: `${__dirname}/./.env` });
const weatherApiPrefix = process.env.OPENWEATHER_API_PREFIX;
const weatherApiKey = process.env.OPENWEATHER_API_KEY;
const googleApiPrefix = process.env.SEARCH_GOOGLE_API_PREFIX;
const youtubeApiPrefix = process.env.SEARCH_YOUTUBE_API_PREFIX;
const commander = new Command();

commander
  .command('weather')
  .alias('w')
  .description('Get weather')
  .action(() => getWeather());

commander
  .command('speed')
  .description('Run a speed test')
  .action(() => getSpeed());

commander
  .command('google')
  .alias('g')
  .description('Run a Google Search')
  .action(() => search(googleApiPrefix, 'Google'));

commander
  .command('youtube')
  .alias('y')
  .description('Run a Youtube Search')
  .action(() => search(youtubeApiPrefix, 'Youtube'));

commander.parse(process.argv);

async function getWeather() {
  // console.log(process.env)
  const spinner = createSpinner(`Loading weather`).start();
  // console.log(weatherApiPrefix);
  // console.log(weatherApiKey);
  const weather = await axios.get(
    `${weatherApiPrefix}?lat=35&lon=139&appid=${weatherApiKey}`
  );
  spinner.success({ text: `temp is ${chalk.blue(weather.data.main.temp)}.` });
}

async function getSpeed() {
  const spinner = createSpinner(`Running speed test`).start();
  const test = speedTest({ maxTime: 5000 });

  test.on('data', (data) => {
    spinner.success({
      text: `\nDownload ${chalk.green(
        data.speeds.download
      )} Mbps\nUpload ${chalk.magenta(
        data.speeds.upload
      )} Mbps\nPing ${chalk.blue(data.server.ping)} ms`,
    });
  });
  test.on('error', () => {
    spinner.error({ text: `\nAn error ocurred. Please try again` });
  });
}

function search(searchPrefix, searchType) {
  console.log(process.argv);
  let searchQuery = '';
  if (process.argv.length > 2) {
    const queryArray = process.argv.slice(1);
    console.log(queryArray);
    searchQuery = queryArray.join('+');
  }
  const searchAddress = searchPrefix + searchQuery;
  // console.log(searchAddress);
  const openCmd = process.platform === 'win32' ? 'start' : 'open';

  console.log(chalk.blue(`Searching on ${searchType}...`));
  setTimeout(() => {
    child_process.exec(`${openCmd} ${searchAddress}`, () => {});
  }, 300);
}
